"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const xmldom_1 = require("xmldom");
const file_1 = __importDefault(require("./file"));
class XmlHelper {
    static getXmlFromArchive(archive, file) {
        return __awaiter(this, void 0, void 0, function* () {
            let xmlDocument = yield file_1.default.extractFromArchive(archive, file);
            const dom = new xmldom_1.DOMParser();
            return dom.parseFromString(xmlDocument);
        });
    }
    static writeXmlToArchive(archive, file, xml) {
        return __awaiter(this, void 0, void 0, function* () {
            let s = new xmldom_1.XMLSerializer();
            let xmlBuffer = s.serializeToString(xml);
            return archive.file(file, xmlBuffer);
        });
    }
    static appendIf(element) {
        return __awaiter(this, void 0, void 0, function* () {
            let xml = yield XmlHelper.getXmlFromArchive(element.archive, element.file);
            if (element.clause !== undefined) {
                if (!element.clause(xml))
                    return false;
            }
            return XmlHelper.append(element);
        });
    }
    static append(element) {
        return __awaiter(this, void 0, void 0, function* () {
            let xml = yield XmlHelper.getXmlFromArchive(element.archive, element.file);
            let newElement = xml.createElement(element.tag);
            for (let attribute in element.attributes) {
                let value = element.attributes[attribute];
                newElement.setAttribute(attribute, (typeof value === 'function') ? value(xml) : value);
            }
            let parent = element.parent(xml);
            parent.appendChild(newElement);
            XmlHelper.writeXmlToArchive(element.archive, element.file, xml);
            return newElement;
        });
    }
    static getNextRelId(rootArchive, file) {
        return __awaiter(this, void 0, void 0, function* () {
            let presentationRelsXml = yield XmlHelper.getXmlFromArchive(rootArchive, file);
            let increment = (max) => 'rId' + max;
            let rid = XmlHelper.getMaxId(presentationRelsXml.documentElement.childNodes, 'Id', true);
            return increment(rid);
        });
    }
    static getMaxId(rels, attribute, increment) {
        let max = 0;
        for (let i in rels) {
            let rel = rels[i];
            if (rel.getAttribute !== undefined) {
                let id = Number(rel.getAttribute(attribute).replace('rId', ''));
                max = (id > max) ? id : max;
            }
        }
        switch (typeof increment) {
            case 'boolean': return ++max;
            default: return max;
        }
    }
    static getTargetsFromRelationships(archive, path, prefix, suffix) {
        return __awaiter(this, void 0, void 0, function* () {
            return XmlHelper.getRelationships(archive, path, (element, rels) => {
                let target = element.getAttribute('Target');
                if (target.indexOf(prefix) === 0) {
                    rels.push({
                        file: target,
                        rId: element.getAttribute('Id'),
                        number: Number(target.replace(prefix, '').replace(suffix || '.xml', ''))
                    });
                }
            });
        });
    }
    static getTargetsByRelationshipType(archive, path, type) {
        return __awaiter(this, void 0, void 0, function* () {
            return XmlHelper.getRelationships(archive, path, (element, rels) => {
                let target = element.getAttribute('Type');
                if (target === type) {
                    rels.push({
                        file: element.getAttribute('Target'),
                        rId: element.getAttribute('Id'),
                    });
                }
            });
        });
    }
    static getRelationships(archive, path, cb) {
        return __awaiter(this, void 0, void 0, function* () {
            let xml = yield XmlHelper.getXmlFromArchive(archive, path);
            let relationships = xml.getElementsByTagName('Relationship');
            let rels = [];
            for (let i in relationships) {
                let element = relationships[i];
                if (element.getAttribute !== undefined) {
                    cb(element, rels);
                }
            }
            return rels;
        });
    }
    static findByAttribute(xml, tagName, attributeName, attributeValue) {
        let elements = xml.getElementsByTagName(tagName);
        for (let i in elements) {
            let element = elements[i];
            if (element.getAttribute !== undefined) {
                if (element.getAttribute(attributeName) === attributeValue) {
                    return true;
                }
            }
        }
        return false;
    }
    static countSlides(presentation) {
        return __awaiter(this, void 0, void 0, function* () {
            let presentationXml = yield XmlHelper.getXmlFromArchive(presentation, 'ppt/presentation.xml');
            let slideCount = presentationXml.getElementsByTagName('p:sldId').length;
            return slideCount;
        });
    }
    static countCharts(presentation) {
        return __awaiter(this, void 0, void 0, function* () {
            let contentTypesXml = yield XmlHelper.getXmlFromArchive(presentation, '[Content_Types].xml');
            let overrides = contentTypesXml.getElementsByTagName('Override');
            let chartCount = 0;
            for (let i in overrides) {
                let override = overrides[i];
                if (override.getAttribute) {
                    let contentType = override.getAttribute('ContentType');
                    if (contentType === `application/vnd.openxmlformats-officedocument.drawingml.chart+xml`) {
                        chartCount++;
                    }
                }
            }
            return chartCount;
        });
    }
    static createContentTypeChild(archive, attributes) {
        return {
            archive: archive,
            file: `[Content_Types].xml`,
            parent: (xml) => xml.getElementsByTagName('Types')[0],
            tag: 'Override',
            attributes: attributes
        };
    }
}
exports.default = XmlHelper;
//# sourceMappingURL=xml.js.map