"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = __importDefault(require("./helper/file"));
const xml_1 = __importDefault(require("./helper/xml"));
class Image {
    constructor(relsXmlInfo, sourceArchive, targetSlideNumber) {
        this.sourceFile = relsXmlInfo.file.replace('../media/', '');
        this.sourceRid = relsXmlInfo.rId;
        this.sourceArchive = sourceArchive;
        this.targetSlideNumber = targetSlideNumber;
        this.contentTypeMap = {
            jpg: "image/jpeg",
            jpeg: "image/jpeg",
            png: "image/png",
            gif: "image/gif",
            svg: "image/svg+xml",
            m4v: "video/mp4",
            mp4: "video/mp4"
        };
    }
    setTarget(archive, number) {
        this.targetArchive = archive;
        this.targetNumber = number;
        this.extension = file_1.default.getFileExtension(this.sourceFile);
        this.targetFile = 'image' + number + '.' + this.extension;
    }
    append() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.copyFiles();
            yield this.appendTypes();
        });
    }
    copyFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            file_1.default.zipCopy(this.sourceArchive, `ppt/media/${this.sourceFile}`, this.targetArchive, `ppt/media/${this.targetFile}`);
        });
    }
    appendTypes() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.editTargetChartRel();
            yield this.appendImageExtensionToContentType();
        });
    }
    editTargetChartRel() {
        return __awaiter(this, void 0, void 0, function* () {
            let targetRelFile = `ppt/slides/_rels/slide${this.targetSlideNumber}.xml.rels`;
            let relXml = yield xml_1.default.getXmlFromArchive(this.targetArchive, targetRelFile);
            let relations = relXml.getElementsByTagName('Relationship');
            for (let i in relations) {
                let element = relations[i];
                if (element.getAttribute) {
                    let rId = element.getAttribute('Id');
                    if (rId === this.sourceRid) {
                        element.setAttribute('Target', `../media/${this.targetFile}`);
                    }
                }
            }
            xml_1.default.writeXmlToArchive(this.targetArchive, targetRelFile, relXml);
        });
    }
    appendImageExtensionToContentType() {
        let extension = this.extension;
        let contentType = (this.contentTypeMap[extension]) ? this.contentTypeMap[extension] : 'image/' + extension;
        return xml_1.default.appendIf(Object.assign(Object.assign({}, xml_1.default.createContentTypeChild(this.targetArchive, {
            Extension: extension,
            ContentType: contentType
        })), { tag: 'Default', clause: (xml) => !xml_1.default.findByAttribute(xml, 'Default', 'Extension', extension) }));
    }
}
exports.default = Image;
//# sourceMappingURL=image.js.map