"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = __importDefault(require("./helper/file"));
const xml_1 = __importDefault(require("./helper/xml"));
class Template {
    constructor(location) {
        this.location = location;
        this.file = file_1.default.readFile(location);
        this.archive = file_1.default.extractFileContent(this.file);
        this.slides = [];
        this.slideCount = 0;
        this.chartCount = 0;
        this.imageCount = 0;
    }
    static importRoot(location) {
        let newTemplate = new Template(location);
        return newTemplate;
    }
    static import(location, name) {
        let newTemplate = new Template(location);
        if (name) {
            newTemplate.name = name;
        }
        return newTemplate;
    }
    appendSlide(slide) {
        return __awaiter(this, void 0, void 0, function* () {
            this.incrementSlideCounter();
            slide.setTarget(yield this.archive, this);
            yield slide.append();
        });
    }
    countSlides() {
        return __awaiter(this, void 0, void 0, function* () {
            let slideCount = yield xml_1.default.countSlides(yield this.archive);
            this.slideCount = slideCount;
            return this.slideCount;
        });
    }
    incrementSlideCounter() {
        this.slideCount++;
        return this.slideCount;
    }
    appendChart(shape) {
        return __awaiter(this, void 0, void 0, function* () {
            shape.setTarget(yield this.archive, this.chartCount);
            yield shape.append();
        });
    }
    countCharts() {
        return __awaiter(this, void 0, void 0, function* () {
            this.chartCount = yield xml_1.default.countCharts(yield this.archive);
            return this.chartCount;
        });
    }
    incrementChartCounter() {
        return ++this.chartCount;
    }
    appendImage(shape) {
        return __awaiter(this, void 0, void 0, function* () {
            shape.setTarget(yield this.archive, this.imageCount);
            yield shape.append();
        });
    }
    countImages() {
        return __awaiter(this, void 0, void 0, function* () {
            this.imageCount = yield file_1.default.countImages(yield this.archive);
            return this.imageCount;
        });
    }
    incrementImageCounter() {
        return ++this.imageCount;
    }
}
exports.default = Template;
//# sourceMappingURL=template.js.map